#
# spec file for package pianobar
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2016 Packman team: http://packman.links2linux.org/
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pianobar
Version:        2022.04.01
Release:        3.2
Summary:        Pandora Player
License:        MIT
Group:          Productivity/Multimedia/Sound/Utilities
URL:            https://6xq.net/pianobar
Source0:        %{url}/pianobar-2022.04.01.tar.bz2
Patch0:         https://github.com/PromyLOPh/pianobar/commit/b11ba432.patch
Patch1:         https://github.com/PromyLOPh/pianobar/commit/8bf4c1bb.patch
BuildRequires:  libgcrypt-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(ao)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(json)
BuildRequires:  pkgconfig(libavcodec) >= 58.7.100
BuildRequires:  pkgconfig(libavfilter) >= 7.0.101
BuildRequires:  pkgconfig(libavformat) >= 58.0.102
BuildRequires:  pkgconfig(libavutil) >= 56.6.100
BuildRequires:  pkgconfig(libcurl)

%description
pianobar is a console client for the personalized web radio pandora

- play and manage (create, add more music, delete, rename, ...) your stations
- rate played songs and let pandora explain why they have been selected
- show upcoming songs/song history
- configure keybindings
- last.fm scrobbling support (external application)
- proxy support for listeners outside the USA

%prep
%autosetup -p1

%build
export CC="gcc"
export CFLAGS="-std=c99 %{optflags}"
make %{?_smp_mflags} V=1

%install
make install PREFIX=%{_prefix} DESTDIR=%{buildroot}

%files
%doc README.rst
%license COPYING
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{ext_man}

%changelog
* Thu Oct 10 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build using FFMPEG 7.1 : Add upstream patches:
  + 8bf4c1bb.patch: ui: Replace deprecated libcurl function.
  + b11ba432.patch player: Adapt to new ffmpeg channel layout API.
* Wed Aug 21 2024 Luigi Baldoni <aloisio@gmx.com>
- Build against ffmpeg-6 on Factory
* Tue Jul 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2022.04.01:
  * Fix compilation with ffmpeg 5.0 and replace deprecated function
  * Improved retry handling with unreliable HTTP proxies
  * Minor UI improvements
- Update source url to main site.
* Tue Apr 13 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2020.11.28
  * Support changing station modes
  * Allow choosing time format
  * Add optional debug output
  version 2020.04.05:
  * Support writing audio to named pipe (audio_pipe)
  * Add resampling (sample_rate)
  * Fix station list not showing more than 95 stations
* Thu Feb 14 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2019.02.14
  * Fix MP3 playback (affects premium subscribers with audio
    quality “high”)
  version 2019.01.25
  * Implement audio buffering
* Sun Jul  8 2018 aloisio@gmx.com
- Update to version 2018.06.22
  * Happy 10th birthday pianobar!
  * Add network timeouts and retries
  * Fix cross-thread memory access
  * Misc UI and documentation improvements
- Use ffmpeg4
* Fri May  4 2018 olaf@aepfle.de
- Use ffmpeg3 versions of pkgconfig(libav*)
* Sat Apr 14 2018 aloisio@gmx.com
- Spec cleanup
* Fri Apr 13 2018 takeda@takeda.tk
- Update to version 2017.08.30
  * Support binding to specific network interface, see config option
    bind_to
  * New config option gain_mul softens effect of replay gain
  * Replaced deprecated ffmpeg and json-c functions, bumps
    ffmpeg/libav version requirement
  * Fix use-after-free
  * Minor improvements to code and documentation
* Sat Sep 24 2016 aloisio@gmx.com
- Update to version 2016.06.02
  * Quit pianobar upon reception of two SIGINT
  * Minor bugfixes
* Wed Dec 23 2015 takeda@takeda.tk
- Update to version 2015.11.22:
  * Switch back to libcurl. tls_fingerprint setting has been replaced by
    ca_bundle
  * Interruptible network transactions (press ^C). Timeouts removed
  * Config file parser fixes and improvements
  * Player respects proxy, replaced deprecated api calls
  * Added ability to change Pandora settings (username, password,
    explicit content filter)
  * The usual minor bugfixes/improvements here and there
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Tue Apr 14 2015 aloisio@gmx.com
- Update to version 2014.09.28
  * Fix segfault when retrieving station’s feedback list
  * Refactored audio player
  * Correctly detect ffmpeg 2.3 and 2.4
  * Restore terminal attributes after waking up (SIGCONT)
  Release 2014.06.08:
  * Switch to ffmpeg/libav for audio playback. ffmpeg 2.2, 2.1
    and 1.2 as well as libav 10 and 9 are supported. libav 8
    does *not* work. libmad/libfaad are not required any more.
  * Tilde-expansion for the fifo setting
  * eventcmd’s songstart reports correct song length
  * Readline improvements
  * Support TLS SNI
  * Improved error messages
